@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.shape");
-Clazz.load (["J.shape.FontLineShape", "JU.P3", "$.V3"], "J.shape.Axes", ["java.lang.Boolean", "JU.PT", "$.SB", "JU.Escape", "JV.JC"], function () {
+Clazz.load (["J.shape.FontLineShape", "JU.P3", "$.V3"], "J.shape.Axes", ["java.lang.Boolean", "JV.JC"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.axisXY = null;
 this.scale = 0;
@@ -117,21 +117,6 @@ axisPoint.z *= this.corner.z * scale;
 }axisPoint.add (this.originPoint);
 }
 }, "~N");
-Clazz.overrideMethod (c$, "getShapeState", 
-function () {
-var sb =  new JU.SB ();
-sb.append ("  axes scale ").appendF (this.vwr.getFloat (570425346)).append (";\n");
-if (this.fixedOrigin != null) sb.append ("  axes center ").append (JU.Escape.eP (this.fixedOrigin)).append (";\n");
-if (this.axisXY.z != 0) sb.append ("  axes position [").appendI (Clazz.floatToInt (this.axisXY.x)).append (" ").appendI (Clazz.floatToInt (this.axisXY.y)).append (" ").append (this.axisXY.z < 0 ? " %" : "").append ("];\n");
-if (this.labels != null) {
-sb.append ("  axes labels ");
-for (var i = 0; i < this.labels.length; i++) if (this.labels[i] != null) sb.append (JU.PT.esc (this.labels[i])).append (" ");
-
-sb.append (";\n");
-}if (this.axisType != null) {
-sb.append ("  axes type " + JU.PT.esc (this.axisType));
-}return this.getShapeStateFL () + sb;
-});
 Clazz.defineStatics (c$,
 "MIN_AXIS_LEN", 1.5);
 });
