@@ -220,14 +220,12 @@ return (occupancies == null || occupancies[this.i] >= 50);
 Clazz.defineMethod (c$, "getBfactor100", 
 function () {
 var bfactor100s = this.group.chain.model.ms.bfactor100s;
-if (bfactor100s == null) return 0;
-return bfactor100s[this.i];
+return (bfactor100s == null ? 0 : bfactor100s[this.i]);
 });
 Clazz.defineMethod (c$, "getHydrophobicity", 
- function () {
+function () {
 var values = this.group.chain.model.ms.hydrophobicities;
-if (values == null) return JU.Elements.getHydrophobicity (this.group.groupID);
-return values[this.i];
+return (values == null ? JU.Elements.getHydrophobicity (this.group.groupID) : values[this.i]);
 });
 Clazz.defineMethod (c$, "setRadius", 
 function (radius) {
@@ -943,7 +941,7 @@ case 1086326786:
 return this.getAtomName ();
 case 1086326785:
 return this.getAtomType ();
-case 1086324740:
+case 1086326788:
 return this.getChainIDStr ();
 case 1086324744:
 return this.getGroup1 ('?');
@@ -981,6 +979,10 @@ return this.getSymmetryOperatorList (true);
 }
 return "";
 }, "JV.Viewer,~N");
+Clazz.overrideMethod (c$, "getInsertionCode", 
+function () {
+return this.group.getInsertionCode ();
+});
 Clazz.defineMethod (c$, "atomPropertyTuple", 
 function (vwr, tok, ptTemp) {
 switch (tok) {
