@@ -147,9 +147,9 @@ if (isZipData) {
 errRet[0] = this.writeZipFile (out, v, "OK JMOL", null);
 return true;
 }objImage = null;
-v.remove (0);
-v.remove (0);
-params.put ("pngImgData", v.remove (0));
+v.removeItemAt (0);
+v.removeItemAt (0);
+params.put ("pngImgData", v.removeItemAt (0));
 var oz = this.getOutputChannel (null, null);
 errRet[0] = this.writeZipFile (oz, v, "OK JMOL", null);
 params.put ("type", "PNGJ");
@@ -157,7 +157,7 @@ type = "Png";
 params.put ("pngAppPrefix", "Jmol Type");
 params.put ("pngAppData", oz.toByteArray ());
 } else if (v.size () == 1) {
-var b = v.remove (0);
+var b = v.removeItemAt (0);
 out.write (b, 0, b.length);
 return true;
 } else {
