@@ -1060,7 +1060,7 @@ break;
 }
 if (list1.size () == 0 || this.undoWorking) return;
 this.undoWorking = true;
-list2.add (0, list1.remove (0));
+list2.add (0, list1.removeItemAt (0));
 s = this.vwr.actionStatesRedo.get (0);
 if (type == 4165 && list2.size () == 1) {
 var pt =  Clazz.newIntArray (-1, [1]);
@@ -1095,7 +1095,7 @@ this.vwr.actionStatesRedo.clear ();
 } else {
 this.vwr.actionStatesRedo.add (1, sb.toString ());
 }if (this.vwr.actionStates.size () == 100) {
-this.vwr.actionStates.remove (99);
+this.vwr.actionStates.removeItemAt (99);
 }}
 this.undoWorking = !clearRedo;
 }, "~N,~N,~B");
