@@ -136,7 +136,7 @@ return false;
 Clazz_defineMethod (c$, "deleteIntegral", 
  function () {
 if (!this.checkSelectedIntegral ()) return;
-this.xyData.remove (this.iSelected);
+this.xyData.removeItemAt (this.iSelected);
 this.iSelected = -1;
 this.iRowColSelected = -1;
 this.applyFromFields ();
