@@ -2,15 +2,15 @@
 d(c$,"addUniqueControls",function(){this.txt1=this.dialog.addTextField("txtBaselineOffset","Baseline Offset",null,"%",""+this.vwr.parameters.integralOffset,!0);this.txt2=this.dialog.addTextField("txtScale","Scale",null,"%",""+this.vwr.parameters.integralRange,!0);this.dialog.addButton("btnApply","Apply");this.addApplyBtn=!1;this.dialog.addButton("btnAuto","Auto");this.dialog.addButton("btnDelete","Delete");this.dialog.addButton("btnNormalize","Normalize")});e(c$,"applyFromFields",function(){this.apply(s(-1,
 [this.dialog.getText(this.txt1),this.dialog.getText(this.txt2)]))});e(c$,"callback",function(a,b){var c;try{if(a.equals("SHOWSELECTION")){for(c=0;c<this.xyData.size();c++)if(JU.DF.formatDecimalDbl(this.xyData.get(c).getXVal(),2).equals(b)){this.iSelected=c;this.jsvp.getPanelData().setXPointers(this.$spec,this.xyData.get(c).getXVal(),this.$spec,this.xyData.get(c).getXVal2());this.jsvp.doRepaint(!0);break}return!0}if(!a.equals("windowClosing")&&!a.equals("FOCUS")){if(a.equals("btnAuto")||null==this.xyData||
 0==this.xyData.size())return this.vwr.runScript("integrate auto"),this.eventApply(),!0;this.setFocus(!0)}if(a.equals("btnDelete"))this.deleteIntegral();else if(a.equals("btnNormalize")){if(!this.checkSelectedIntegral())return!0;var f=this.manager.getDialogInput(this.dialog,"Enter a normalization factor","Normalize",3,null,null,""+this.lastNorm);c=Double.parseDouble(f);0<c&&this.xyData.setSelectedIntegral(this.xyData.get(this.iSelected),this.lastNorm=c);this.eventApply()}else return this.callbackAD(a,
-b)}catch(l){if(!t(l,Exception))throw l;}return!0},"~S,~S");d(c$,"checkSelectedIntegral",function(){return 0>this.iSelected?(this.showMessage("Select a line on the table first, then click this button.","Integration",1),!1):!0});d(c$,"deleteIntegral",function(){this.checkSelectedIntegral()&&(this.xyData.remove(this.iSelected),this.iRowColSelected=this.iSelected=-1,this.applyFromFields())});n(c$,"posXY",k(-1,[-2147483648,0]))});h("JSV.dialog");g(["JSV.dialog.JSVDialog"],"JSV.dialog.PeakListDialog",["JSV.common.Annotation"],
-function(){c$=p(JSV.dialog,"PeakListDialog",JSV.dialog.JSVDialog);j(c$,function(){m(this,JSV.dialog.PeakListDialog,[]);this.type=JSV.common.Annotation.AType.PeakList});e(c$,"getPosXY",function(){return JSV.dialog.PeakListDialog.posXY});d(c$,"addUniqueControls",function(){this.txt1=this.dialog.addTextField("txtThreshold","Threshold",null,"","",!0);this.setThreshold(NaN);this.combo1=this.dialog.addSelectOption("cmbInterpolation","Interpolation",s(-1,["parabolic","none"]),0,!0)});e(c$,"callback",function(a,
-b){if(a.equals("cmbInterpolation")||a.equals("txtThreshold"))a="btnApply";return this.callbackAD(a,b)},"~S,~S");n(c$,"posXY",k(-1,[-2147483648,0]))});h("JSV.dialog");g(["JSV.dialog.JSVDialog"],"JSV.dialog.MeasurementsDialog",["JSV.common.Annotation"],function(){c$=p(JSV.dialog,"MeasurementsDialog",JSV.dialog.JSVDialog);j(c$,function(){m(this,JSV.dialog.MeasurementsDialog,[]);this.type=JSV.common.Annotation.AType.Measurements});d(c$,"addUniqueControls",function(){});e(c$,"getPosXY",function(){return JSV.dialog.MeasurementsDialog.posXY});
-e(c$,"callback",function(a,b){return this.callbackAD(a,b)},"~S,~S");n(c$,"posXY",k(-1,[-2147483648,0]))});h("JSV.dialog");g(["JSV.dialog.JSVDialog"],"JSV.dialog.OverlayLegendDialog",["JSV.common.Annotation"],function(){c$=p(JSV.dialog,"OverlayLegendDialog",JSV.dialog.JSVDialog);j(c$,function(){m(this,JSV.dialog.OverlayLegendDialog,[]);this.type=JSV.common.Annotation.AType.OverlayLegend});e(c$,"getPosXY",function(){return JSV.dialog.OverlayLegendDialog.posXY});d(c$,"addUniqueControls",function(){});
-e(c$,"callback",function(){return!1},"~S,~S");n(c$,"posXY",k(-1,[-2147483648,0]))});h("JSV.dialog");g(["JSV.dialog.JSVDialog"],"JSV.dialog.ViewsDialog",["JU.Lst","$.PT","$.SB","JSV.common.Annotation"],function(){c$=r(function(){this.viewSelectedButton=this.combineSelectedButton=this.closeSelectedButton=this.checkBoxes=this.treeNodes=null;this.checking=!1;q(this,arguments)},JSV.dialog,"ViewsDialog",JSV.dialog.JSVDialog);j(c$,function(){m(this,JSV.dialog.ViewsDialog,[]);this.type=JSV.common.Annotation.AType.Views});
-e(c$,"getPosXY",function(){return JSV.dialog.ViewsDialog.posXY});d(c$,"addUniqueControls",function(){this.checkBoxes=new JU.Lst;this.treeNodes=new JU.Lst;this.dialog.addButton("btnSelectAll","Select All");this.dialog.addButton("btnSelectNone","Select None");this.txt2=this.dialog.addTextField("txtOffset","Offset",""+this.vwr.parameters.viewOffset,"%",null,!0);this.viewSelectedButton=this.dialog.addButton("btnViewSelected","View Selected");this.combineSelectedButton=this.dialog.addButton("btnCombineSelected",
-"Combine Selected");this.closeSelectedButton=this.dialog.addButton("btnCloseSelected","Close Selected");this.dialog.addButton("btnDone","Done");this.dialog.setPreferredSize(500,350);this.txt1=this.dialog.addCheckBox(null,null,0,!1);this.addCheckBoxes(this.vwr.spectraTree.getRootNode(),0,!0);this.addCheckBoxes(this.vwr.spectraTree.getRootNode(),0,!1)});d(c$,"addCheckBoxes",function(a,b,c){for(a=a.children();a.hasMoreElements();){var f=a.nextElement(),l=f.getPanelNode();if(l.isView==c){var d=l.toString();
-0<=d.indexOf("\n")&&(d=d.substring(0,d.indexOf("\n")));var e="chkBox"+this.treeNodes.size(),l=this.dialog.addCheckBox(e,d,b,l.isSelected);f.setIndex(this.treeNodes.size());this.treeNodes.addLast(f);this.checkBoxes.addLast(l);this.addCheckBoxes(f,b+1,c)}}},"JSV.api.JSVTreeNode,~N,~B");e(c$,"checkEnables",function(){for(var a=0,b=0;b<this.checkBoxes.size();b++)this.dialog.isSelected(this.checkBoxes.get(b))&&null!=this.treeNodes.get(b).getPanelNode().jsvp&&a++;System.out.println("viewsdialog n="+a);
-this.dialog.setEnabled(this.closeSelectedButton,0<a);this.dialog.setEnabled(this.combineSelectedButton,1<a);this.dialog.setEnabled(this.viewSelectedButton,1==a)});d(c$,"check",function(a){var b=JU.PT.parseInt(a.substring(a.indexOf("_")+1));a=this.treeNodes.get(b);var c=this.checkBoxes.get(b),b=this.dialog.isSelected(c);if(null==a.getPanelNode().jsvp){!this.checking&&(b&&this.dialog.getText(c).startsWith("Overlay"))&&(this.checking=!0,this.selectAll(!1),this.dialog.setSelected(c,!0),a.getPanelNode().isSelected=
+b)}catch(l){if(!t(l,Exception))throw l;}return!0},"~S,~S");d(c$,"checkSelectedIntegral",function(){return 0>this.iSelected?(this.showMessage("Select a line on the table first, then click this button.","Integration",1),!1):!0});d(c$,"deleteIntegral",function(){this.checkSelectedIntegral()&&(this.xyData.removeItemAt(this.iSelected),this.iRowColSelected=this.iSelected=-1,this.applyFromFields())});n(c$,"posXY",k(-1,[-2147483648,0]))});h("JSV.dialog");g(["JSV.dialog.JSVDialog"],"JSV.dialog.PeakListDialog",
+["JSV.common.Annotation"],function(){c$=p(JSV.dialog,"PeakListDialog",JSV.dialog.JSVDialog);j(c$,function(){m(this,JSV.dialog.PeakListDialog,[]);this.type=JSV.common.Annotation.AType.PeakList});e(c$,"getPosXY",function(){return JSV.dialog.PeakListDialog.posXY});d(c$,"addUniqueControls",function(){this.txt1=this.dialog.addTextField("txtThreshold","Threshold",null,"","",!0);this.setThreshold(NaN);this.combo1=this.dialog.addSelectOption("cmbInterpolation","Interpolation",s(-1,["parabolic","none"]),0,
+!0)});e(c$,"callback",function(a,b){if(a.equals("cmbInterpolation")||a.equals("txtThreshold"))a="btnApply";return this.callbackAD(a,b)},"~S,~S");n(c$,"posXY",k(-1,[-2147483648,0]))});h("JSV.dialog");g(["JSV.dialog.JSVDialog"],"JSV.dialog.MeasurementsDialog",["JSV.common.Annotation"],function(){c$=p(JSV.dialog,"MeasurementsDialog",JSV.dialog.JSVDialog);j(c$,function(){m(this,JSV.dialog.MeasurementsDialog,[]);this.type=JSV.common.Annotation.AType.Measurements});d(c$,"addUniqueControls",function(){});
+e(c$,"getPosXY",function(){return JSV.dialog.MeasurementsDialog.posXY});e(c$,"callback",function(a,b){return this.callbackAD(a,b)},"~S,~S");n(c$,"posXY",k(-1,[-2147483648,0]))});h("JSV.dialog");g(["JSV.dialog.JSVDialog"],"JSV.dialog.OverlayLegendDialog",["JSV.common.Annotation"],function(){c$=p(JSV.dialog,"OverlayLegendDialog",JSV.dialog.JSVDialog);j(c$,function(){m(this,JSV.dialog.OverlayLegendDialog,[]);this.type=JSV.common.Annotation.AType.OverlayLegend});e(c$,"getPosXY",function(){return JSV.dialog.OverlayLegendDialog.posXY});
+d(c$,"addUniqueControls",function(){});e(c$,"callback",function(){return!1},"~S,~S");n(c$,"posXY",k(-1,[-2147483648,0]))});h("JSV.dialog");g(["JSV.dialog.JSVDialog"],"JSV.dialog.ViewsDialog",["JU.Lst","$.PT","$.SB","JSV.common.Annotation"],function(){c$=r(function(){this.viewSelectedButton=this.combineSelectedButton=this.closeSelectedButton=this.checkBoxes=this.treeNodes=null;this.checking=!1;q(this,arguments)},JSV.dialog,"ViewsDialog",JSV.dialog.JSVDialog);j(c$,function(){m(this,JSV.dialog.ViewsDialog,
+[]);this.type=JSV.common.Annotation.AType.Views});e(c$,"getPosXY",function(){return JSV.dialog.ViewsDialog.posXY});d(c$,"addUniqueControls",function(){this.checkBoxes=new JU.Lst;this.treeNodes=new JU.Lst;this.dialog.addButton("btnSelectAll","Select All");this.dialog.addButton("btnSelectNone","Select None");this.txt2=this.dialog.addTextField("txtOffset","Offset",""+this.vwr.parameters.viewOffset,"%",null,!0);this.viewSelectedButton=this.dialog.addButton("btnViewSelected","View Selected");this.combineSelectedButton=
+this.dialog.addButton("btnCombineSelected","Combine Selected");this.closeSelectedButton=this.dialog.addButton("btnCloseSelected","Close Selected");this.dialog.addButton("btnDone","Done");this.dialog.setPreferredSize(500,350);this.txt1=this.dialog.addCheckBox(null,null,0,!1);this.addCheckBoxes(this.vwr.spectraTree.getRootNode(),0,!0);this.addCheckBoxes(this.vwr.spectraTree.getRootNode(),0,!1)});d(c$,"addCheckBoxes",function(a,b,c){for(a=a.children();a.hasMoreElements();){var f=a.nextElement(),l=f.getPanelNode();
+if(l.isView==c){var d=l.toString();0<=d.indexOf("\n")&&(d=d.substring(0,d.indexOf("\n")));var e="chkBox"+this.treeNodes.size(),l=this.dialog.addCheckBox(e,d,b,l.isSelected);f.setIndex(this.treeNodes.size());this.treeNodes.addLast(f);this.checkBoxes.addLast(l);this.addCheckBoxes(f,b+1,c)}}},"JSV.api.JSVTreeNode,~N,~B");e(c$,"checkEnables",function(){for(var a=0,b=0;b<this.checkBoxes.size();b++)this.dialog.isSelected(this.checkBoxes.get(b))&&null!=this.treeNodes.get(b).getPanelNode().jsvp&&a++;System.out.println("viewsdialog n="+
+a);this.dialog.setEnabled(this.closeSelectedButton,0<a);this.dialog.setEnabled(this.combineSelectedButton,1<a);this.dialog.setEnabled(this.viewSelectedButton,1==a)});d(c$,"check",function(a){var b=JU.PT.parseInt(a.substring(a.indexOf("_")+1));a=this.treeNodes.get(b);var c=this.checkBoxes.get(b),b=this.dialog.isSelected(c);if(null==a.getPanelNode().jsvp){!this.checking&&(b&&this.dialog.getText(c).startsWith("Overlay"))&&(this.checking=!0,this.selectAll(!1),this.dialog.setSelected(c,!0),a.getPanelNode().isSelected=
 !0,this.checking=!1);for(c=a.children();c.hasMoreElements();){var f=c.nextElement();this.dialog.setSelected(this.checkBoxes.get(f.getIndex()),b);f.getPanelNode().isSelected=b;a.getPanelNode().isSelected=b}}else a.getPanelNode().isSelected=b;if(b)for(b=this.treeNodes.size();0<=--b;)this.treeNodes.get(b).getPanelNode().isView!=a.getPanelNode().isView&&(this.dialog.setSelected(this.checkBoxes.get(this.treeNodes.get(b).getIndex()),!1),this.treeNodes.get(b).getPanelNode().isSelected=!1);this.checkEnables()},
 "~S");d(c$,"selectAll",function(a){for(var b=this.checkBoxes.size();0<=--b;)this.dialog.setSelected(this.checkBoxes.get(b),a),this.treeNodes.get(b).getPanelNode().isSelected=a;this.checkEnables()},"~B");d(c$,"combineSelected",function(){});d(c$,"viewSelected",function(){for(var a=new JU.SB,b=null,c=0,f=0;f<this.checkBoxes.size();f++){var d=this.checkBoxes.get(f),e=this.treeNodes.get(f).getPanelNode();if(this.dialog.isSelected(d)&&null!=e.jsvp){if(e.isView){b=e;c=2;break}c++;d=this.dialog.getText(d);
 a.append(" ").append(d.substring(0,d.indexOf(":")))}}f=null;1<c&&(this.eventApply(),f="STACKOFFSETY "+this.vwr.parameters.viewOffset);null==b?(this.vwr.execView(a.toString().trim(),!1),this.layoutDialog()):this.vwr.setNode(b);null!=f&&this.vwr.runScript(f)});d(c$,"closeSelected",function(){this.vwr.runScript("close !selected");this.layoutDialog()});e(c$,"callback",function(a,b){if(a.equals("btnSelectAll"))this.selectAll(!0);else if(a.equals("btnSelectNone"))this.selectAll(!1);else if(a.equals("btnViewSelected"))this.viewSelected();
