@@ -65,12 +65,12 @@ b,c,d,e){if(this.vwr.g.preserveState){var f=new JU.SB;d=(null==d?JM.AtomCollecti
 break;case 15:f.appendI(h[j].group.getResno());break;case 14:f.appendI(h[j].getSeqID());break;case 0:f.append(h[j].getAtomName());break;case 1:f.append(h[j].getAtomType());break;case 2:JV.StateCreator.isTainted(m,j,2)&&(k=!1);f.appendF(h[j].x).append(" ").appendF(h[j].y).append(" ").appendF(h[j].z);break;case 12:var l=h[j].getVibrationVector();null==l?f.append("0 0 0"):Float.isNaN(l.modScale)?f.appendF(l.x).append(" ").appendF(l.y).append(" ").appendF(l.z):f.appendF(1.4E-45).append(" ").appendF(1.4E-45).append(" ").appendF(l.modScale);
 break;case 3:f.appendI(h[j].getAtomicAndIsotopeNumber());break;case 4:f.appendI(h[j].getFormalCharge());break;case 6:f.appendF(h[j].getBondingRadius());break;case 7:f.appendI(h[j].getOccupancy100());break;case 8:f.appendF(h[j].getPartialCharge());break;case 9:f.appendF(h[j].getBfactor100()/100);break;case 10:f.appendI(h[j].getValence());break;case 11:f.appendF(h[j].getVanderwaalsRadiusFloat(this.vwr,J.c.VDW.AUTO))}f.append(" ;\n");++g}0!=g&&(k&&(d+="(default)"),a.append('\n  DATA "'+d+'"\n').appendI(g).append(" ;\nJmol Property Data Format 1 -- Jmol ").append(JV.Viewer.getJmolVersion()).append(";\n"),
 a.appendSB(f),a.append('  end "'+d+'";\n'))}},"JU.SB,~N,JU.BS,~S,~A");l(c$,"undoMoveAction",function(a,b){switch(a){case 4165:case 4139:switch(b){case -2:this.vwr.undoClear();break;case -1:(4165==a?this.vwr.actionStates:this.vwr.actionStatesRedo).clear();break;case 0:b=2147483647;default:100<b&&(b=(4165==a?this.vwr.actionStates:this.vwr.actionStatesRedo).size());for(var c=0;c<b;c++)this.undoMoveActionClear(0,a,!0)}}},"~N,~N");l(c$,"undoMoveActionClear",function(a,b,c){if(this.vwr.g.preserveState){var d=
-0<=a?this.vwr.ms.at[a].mi:this.vwr.ms.mc-1;switch(b){case 4139:case 4165:this.vwr.stopMinimization();var e="";switch(b){default:case 4165:e=this.vwr.actionStates;a=this.vwr.actionStatesRedo;break;case 4139:if(e=this.vwr.actionStatesRedo,a=this.vwr.actionStates,1==this.vwr.actionStatesRedo.size())return}if(0==e.size()||this.undoWorking)return;this.undoWorking=!0;a.add(0,e.remove(0));e=this.vwr.actionStatesRedo.get(0);4165==b&&1==a.size()&&(a=x(-1,[1]),b=JU.PT.parseIntNext(e,a),a=JU.PT.parseIntNext(e,
+0<=a?this.vwr.ms.at[a].mi:this.vwr.ms.mc-1;switch(b){case 4139:case 4165:this.vwr.stopMinimization();var e="";switch(b){default:case 4165:e=this.vwr.actionStates;a=this.vwr.actionStatesRedo;break;case 4139:if(e=this.vwr.actionStatesRedo,a=this.vwr.actionStates,1==this.vwr.actionStatesRedo.size())return}if(0==e.size()||this.undoWorking)return;this.undoWorking=!0;a.add(0,e.removeItemAt(0));e=this.vwr.actionStatesRedo.get(0);4165==b&&1==a.size()&&(a=x(-1,[1]),b=JU.PT.parseIntNext(e,a),a=JU.PT.parseIntNext(e,
 a),this.undoMoveActionClear(a,b,!1));this.vwr.ms.am[d].isModelKit||0>e.indexOf("zap ")?(JU.Logger.debugging&&this.vwr.log(e),this.vwr.evalStringQuiet(e)):this.vwr.actionStates.clear();break;default:if(this.undoWorking&&c)return;this.undoWorking=!0;e=new JU.SB;e.append("#"+b+" "+a+" "+new java.util.Date+"\n");0<=a?(d=this.vwr.getModelUndeletedAtomsBitSet(d),this.vwr.ms.taintAtoms(d,b),e.append(this.getAtomicPropertyState(-1,null))):(d=this.vwr.getModelUndeletedAtomsBitSet(d),e.append("zap "),e.append(JU.Escape.eBS(d)).append(";"),
-this.getInlineData(e,this.vwr.getModelExtract(d,!1,!0,"MOL"),!0,null),e.append("set refreshing false;").append(this.vwr.acm.getPickingState()).append(this.vwr.tm.getMoveToText(0,!1)).append("set refreshing true;"));c?(this.vwr.actionStates.add(0,e.toString()),this.vwr.actionStatesRedo.clear()):this.vwr.actionStatesRedo.add(1,e.toString());100==this.vwr.actionStates.size()&&this.vwr.actionStates.remove(99)}this.undoWorking=!c}},"~N,~N,~B");l(c$,"syncScript",function(a,b,c){var d=this.vwr.sm;if("GET_GRAPHICS".equalsIgnoreCase(a))d.setSyncDriver(5),
-d.syncSend(a,b,0),this.vwr.setBooleanProperty("_syncMouse",!1),this.vwr.setBooleanProperty("_syncScript",!1);else{"=".equals(b)&&(b="~",d.setSyncDriver(2));var e="~".equals(b);if(0<c||!e&&!".".equals(b))if(d.syncSend(a,b,c),!"*".equals(b)||a.startsWith("{"))return;if(a.equalsIgnoreCase("on")||a.equalsIgnoreCase("true"))d.setSyncDriver(1);else if(a.equalsIgnoreCase("off")||a.equalsIgnoreCase("false"))d.setSyncDriver(0);else if(a.equalsIgnoreCase("slave"))d.setSyncDriver(2);else if(b=d.getSyncMode(),
-0!=b)if(1!=b&&(e=!1),JU.Logger.debugging&&JU.Logger.debug(this.vwr.htmlName+" syncing with script: "+a),e&&d.setSyncDriver(3),0!=a.indexOf("Mouse: ")){b=JV.JC.getServiceCommand(a);switch(b){case 70:case 42:case 49:case 56:case 63:d.syncSend(a,".",c);return;case 0:case 77:case 28:case 35:if(e)return;case 21:case 7:case 14:if(null==(a=this.vwr.getJSV().processSync(a,b)))return}this.vwr.evalStringQuietSync(a,!0,!1)}else this.mouseScript(a),e&&this.vwr.setSyncDriver(4)}},"~S,~S,~N");l(c$,"mouseScript",
-function(a){var b=JU.PT.getTokens(a),c=b[1];try{switch(c=(c.toLowerCase()+"...............").substring(0,15),"zoombyfactor...zoomby.........rotatezby......rotatexyby.....translatexyby..rotatemolecule.spinxyby.......rotatearcball..".indexOf(c)){case 0:switch(b.length){case 3:this.vwr.zoomByFactor(JU.PT.parseFloat(b[2]),2147483647,2147483647);return;case 5:this.vwr.zoomByFactor(JU.PT.parseFloat(b[2]),JU.PT.parseInt(b[3]),JU.PT.parseInt(b[4]));return}break;case 15:switch(b.length){case 3:this.vwr.zoomBy(JU.PT.parseInt(b[2]));
+this.getInlineData(e,this.vwr.getModelExtract(d,!1,!0,"MOL"),!0,null),e.append("set refreshing false;").append(this.vwr.acm.getPickingState()).append(this.vwr.tm.getMoveToText(0,!1)).append("set refreshing true;"));c?(this.vwr.actionStates.add(0,e.toString()),this.vwr.actionStatesRedo.clear()):this.vwr.actionStatesRedo.add(1,e.toString());100==this.vwr.actionStates.size()&&this.vwr.actionStates.removeItemAt(99)}this.undoWorking=!c}},"~N,~N,~B");l(c$,"syncScript",function(a,b,c){var d=this.vwr.sm;
+if("GET_GRAPHICS".equalsIgnoreCase(a))d.setSyncDriver(5),d.syncSend(a,b,0),this.vwr.setBooleanProperty("_syncMouse",!1),this.vwr.setBooleanProperty("_syncScript",!1);else{"=".equals(b)&&(b="~",d.setSyncDriver(2));var e="~".equals(b);if(0<c||!e&&!".".equals(b))if(d.syncSend(a,b,c),!"*".equals(b)||a.startsWith("{"))return;if(a.equalsIgnoreCase("on")||a.equalsIgnoreCase("true"))d.setSyncDriver(1);else if(a.equalsIgnoreCase("off")||a.equalsIgnoreCase("false"))d.setSyncDriver(0);else if(a.equalsIgnoreCase("slave"))d.setSyncDriver(2);
+else if(b=d.getSyncMode(),0!=b)if(1!=b&&(e=!1),JU.Logger.debugging&&JU.Logger.debug(this.vwr.htmlName+" syncing with script: "+a),e&&d.setSyncDriver(3),0!=a.indexOf("Mouse: ")){b=JV.JC.getServiceCommand(a);switch(b){case 70:case 42:case 49:case 56:case 63:d.syncSend(a,".",c);return;case 0:case 77:case 28:case 35:if(e)return;case 21:case 7:case 14:if(null==(a=this.vwr.getJSV().processSync(a,b)))return}this.vwr.evalStringQuietSync(a,!0,!1)}else this.mouseScript(a),e&&this.vwr.setSyncDriver(4)}},"~S,~S,~N");
+l(c$,"mouseScript",function(a){var b=JU.PT.getTokens(a),c=b[1];try{switch(c=(c.toLowerCase()+"...............").substring(0,15),"zoombyfactor...zoomby.........rotatezby......rotatexyby.....translatexyby..rotatemolecule.spinxyby.......rotatearcball..".indexOf(c)){case 0:switch(b.length){case 3:this.vwr.zoomByFactor(JU.PT.parseFloat(b[2]),2147483647,2147483647);return;case 5:this.vwr.zoomByFactor(JU.PT.parseFloat(b[2]),JU.PT.parseInt(b[3]),JU.PT.parseInt(b[4]));return}break;case 15:switch(b.length){case 3:this.vwr.zoomBy(JU.PT.parseInt(b[2]));
 return}break;case 30:switch(b.length){case 3:this.vwr.rotateZBy(JU.PT.parseInt(b[2]),2147483647,2147483647);return;case 5:this.vwr.rotateZBy(JU.PT.parseInt(b[2]),JU.PT.parseInt(b[3]),JU.PT.parseInt(b[4]))}break;case 45:this.vwr.rotateXYBy(JU.PT.parseFloat(b[2]),JU.PT.parseFloat(b[3]));return;case 60:this.vwr.translateXYBy(JU.PT.parseInt(b[2]),JU.PT.parseInt(b[3]));return;case 75:this.vwr.rotateSelected(JU.PT.parseFloat(b[2]),JU.PT.parseFloat(b[3]),null);return;case 90:this.vwr.spinXYBy(JU.PT.parseInt(b[2]),
 JU.PT.parseInt(b[3]),JU.PT.parseFloat(b[4]));return;case 105:this.vwr.rotateXYBy(JU.PT.parseInt(b[2]),JU.PT.parseInt(b[3]));return}}catch(d){if(!s(d,Exception))throw d;}this.vwr.showString("error reading SYNC command: "+a,!1)},"~S");y(c$,"MAX_ACTION_UNDO",100)})})(Clazz,Clazz.getClassName,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,
 Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,
